.. _pycatia.readthedocs.io: https://pycatia.readthedocs.io
.. _pypi.org: https://pypi.org/project/pycatia/

pycatia
=======

pycatia was primarily created to access the CATIA API Measurable
object and it's methods without the need of visual basic / CATScripts.
There is further functionaliy available which can be seen by looking at
the examples provided and reading the API at pycatia.readthedocs.io_.


Some of the methods can be accessed simply using the pywin32 module but further 
access to methods such as GetCOG do not seem to be accessible using pure python.
There are several questions on stack overflow and the pywin32 mailing list regarding
this. But, they fail to provide any working examples with the VB Measurable object 
in python. 

pycatia accesses these methods by running VBA scripts using the 
`Dispatch('CATIA.Application').SystemService.Evaluate()` function where required
and passing a small public function to it. Otherwise, pycatia uses the VB method
directly but exposes it within the same python class.

This has currently only been tested in CATIA V5 R21.

Requirements
------------

* python >= 3.6 
* CATIA V5
* see requirements.txt

Installation
------------

with pip
~~~~~~~~

.. code-block:: python

    pip install pycatia


For more detailed instructions please refer to the installation instructions
available at pycatia.readthedocs.io_.


Usage
-----

See the examples provided.


Links
-----

Documentation: pycatia.readthedocs.io_.

Releases: pycatia @ pypi.org_

Examples
--------

.. _example_1: https://github.com/evereux/pycatia/blob/master/example_1.py
.. _example_2: https://github.com/evereux/pycatia/blob/master/example_2.py
.. _example_3: https://github.com/evereux/pycatia/blob/master/example_3.py
.. _example_4: https://github.com/evereux/pycatia/blob/master/example_4.py
.. _example_5: https://github.com/evereux/pycatia/blob/master/example_5.py
.. _example_6: https://github.com/evereux/pycatia/blob/master/example_6.py
.. _example_7: https://github.com/evereux/pycatia/blob/master/example_7.py
.. _example_8: https://github.com/evereux/pycatia/blob/master/example_8.py
.. _example_9: https://github.com/evereux/pycatia/blob/master/example_9.py
.. _example_10: https://github.com/evereux/pycatia/blob/master/example_10.py
.. _example_11: https://github.com/evereux/pycatia/blob/master/example_11.py

Asking Questions
----------------

Please don't raise an issue here until you have read the documentation, understood and met the requirements (YOU NEED
CATIA INSTALLED) and have run the examples.

If you are upgrading from an earlier versions and your scripts break please check the changelog to give you clues on
what to do to resolve those issues.

Once you have done that please give as much information as you can so I may
try and reproduce the issue. Please provide the following information:

* Windows OS version
* CATIA version
* Python version
* pycatia version
* Your code!
* Full stack trace of error you encounter (properly formatted text please, not picture).

Thanks! :-)

Running The Tests
-----------------
To run the tests with coverage:

.. code-block:: python

    py.test -v --cov-report term-missing --cov=pycatia

To run a specific test:

.. code-block:: python

    py.test -v tests/test_product.py::test_move
